#========================================================================================
# package      DE_EPAGES::Catalog::UI::JSON
# state        public
#----------------------------------------------------------------------------------------
# description  UI handler to add selected products to a category
#========================================================================================
package DE_EPAGES::Catalog::UI::JSON;
use parent DE_EPAGES::Presentation::UI::JSON;

use strict;

use DE_EPAGES::Catalog::API::Catalog qw ( AssignProductToCategory RenumberCategoryProducts );
use DE_EPAGES::Catalog::API::Object qw ( CollectJSONLayoutInfomation );
use DE_EPAGES::Object::API::Factory qw ( Transaction );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Trigger::API::BatchProcessor qw ( RunBatchProcess );

use HTML::Entities qw( encode_entities );

sub JSONInsertProducts {
    my $self = shift;
    my ($Servlet) = @_;

    my $Category = $Servlet->object;
    my $Shop = $Category->getSite;
    my @ProductIDs = $Servlet->form->value('ProductIDs');
    my $aProducts = $Shop->loadObjects(\@ProductIDs, 'Product');

    RunBatchProcess('UpdateProducts', sub{
        Transaction( sub {
            foreach my $Product (@$aProducts) {
                AssignProductToCategory($Product, $Category);
            }
            RenumberCategoryProducts($Category);
        });
    });

    $Category->updatePageCache;
    return;
}

sub JSONLayout {
    my $self = shift;
    my ($Servlet) = @_;
    my @KnownPageTypes = $Servlet->form->value('KnownPageTypes');
    my $hInfo = CollectJSONLayoutInfomation($Servlet->object, \@KnownPageTypes);
    $self->writeContentOutput($hInfo);

    return;
}

#========================================================================================
# function JSONUnityAssignCategories
# state public
#----------------------------------------------------------------------------------------
# syntax $Handler->JSONUnityAssignCategories($Servlet);
#----------------------------------------------------------------------------------------
# description Called to create the JSON string for assigning categories to a new product
#----------------------------------------------------------------------------------------
# input $Servlet | servlet object | object
#========================================================================================
sub JSONUnityAssignCategories {
    my $self = shift;
    my ($Servlet) = @_;

    my $ProductFolder = $Servlet->object;
    my $Form          = $Servlet->form;

    my $Shop       = $ProductFolder->getSite();
    my $LocaleID   = $Servlet->locale();
    my $Locale     = DE_EPAGES::Object::API::Object::Locale->load($LocaleID);
    my $LanguageID = $Locale->get('LanguageID');

    my @CategoryIDs = $Form->value('CategoryID');

    my @Categories;

    foreach my $CategoryID (grep { /\S/ } @CategoryIDs) {
        my $Category = $Shop->loadObject($CategoryID, 'Category');
        push(@Categories, {
            'CategoryID'   => $CategoryID,
            # encode html tags to avoid XSS (UNITY-4106)
            'CategoryName' => encode_entities($Category->get('NameOrAlias', $LanguageID))
        });
    }

    my $Response = {'Categories' => \@Categories};

    $self->writeContentOutput($Response);
}

1;
