#==============================================================================
# §package      DE_EPAGES::Content::API::TLE::ContentObject
# §state        public
#==============================================================================
package DE_EPAGES::Content::API::TLE::ContentObject;

use strict;
use DE_EPAGES::Core::API::Log   qw( GetLog LogError );
use DE_EPAGES::Core::API::Error qw( ExistsError GetError );
use MIME::Base64;
use utf8;

sub RegisterHandlerProc {
    my ($Params) = @_;
    GetLog->debug( 'ContentObject.RegisterHandlerProc' );

    __PACKAGE__->new()->register( $Params->{'Processor'} );
}

sub new { bless {}, shift; }

#========================================================================================
# §function     register
# §state        private
#----------------------------------------------------------------------------------------
# §syntax       $Handler->register( $Processor );
#----------------------------------------------------------------------------------------
# §description  Registers this handle on the processor
#----------------------------------------------------------------------------------------
# §input        $Processor | tle processor | object
#========================================================================================
sub register {
    my $self = shift;
    my ($Processor) = @_;
    GetLog->debug( 'ContentObject.register' );

    $Processor->registerHandler('FunctionHandler', $self, 'IsInProductDetailPage');

    return;
}

#========================================================================================
# §function     IsInProductDetailPage
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       #IsInProductDetailPage(#Object, #VIEWACTION.Alias)
#----------------------------------------------------------------------------------------
# §description  TLE to determine if a user is on the mbo product page.
#----------------------------------------------------------------------------------------
# §input        $Object, $ViewActionAlias
#----------------------------------------------------------------------------------------
# return        1 or 0 | 1, if customer is on a mbo produtc page, 0 otherwise | int
#========================================================================================
sub IsInProductDetailPage {
    my $self = shift;
    my ($Processor, $aParams) = @_;
    my ($Object, $ViewActionAlias) = @$aParams;

    my $Result = eval {
        $self->_isInProductDetailPage($Object, $ViewActionAlias);
    };
    if ( ExistsError() ) {
        LogError(GetError());
        $Result = 0;
    }

    return $Result;
}

#========================================================================================
# §function     _isInProductDetailPage
# §state        private
#----------------------------------------------------------------------------------------
# §syntax       $self->_isInProductDetailPage($Object, $ViewActionAlias);
#----------------------------------------------------------------------------------------
# §description  Method to determine if a user is on the mbo product page.
#----------------------------------------------------------------------------------------
# §input        $Object, $ViewActionAlias
#----------------------------------------------------------------------------------------
# return        true or false | true, if customer is on a mbo product page | boolean
#========================================================================================
sub _isInProductDetailPage {
    my $self = shift;
    my ($Object, $ViewActionAlias) = @_;

    return 1 if ($Object->instanceOf('Product') && $ViewActionAlias eq 'MBO-ViewGeneral');
    return 0;
}

1;
