#========================================================================================
# package      DE_EPAGES::Ebay::Hooks::MailType
# state        public
# description  runs when order-related mails are being sent.
#========================================================================================
package DE_EPAGES::Ebay::Hooks::MailType;

use strict;
use DE_EPAGES::Object::API::Factory qw ( LoadClassByAlias );

#========================================================================================
# function     OnMailTypeSend
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnMailTypeSend( $hParams );
#----------------------------------------------------------------------------------------
# description  OnMailTypeSend is executed when the Hook MailTypeSend is triggered.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>MailType      - mail type to send    - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnMailTypeSend {
    my ($hParams) = @_;
    my $MailType  = $hParams->{'MailType'};
    my $Object    = $hParams->{'Object'};

    my $IsEbayEvent = 0;
    if ($Object->instanceOf('Shop')) {
        # only check the event "FulfillEbayTransaction" for the shop object
        my $MailAlias = $MailType->get('MailTypeTemplate')->alias;
        $IsEbayEvent = 1 if $MailAlias eq "FulfillEbayTransaction";
    } elsif ($Object->instanceOf('CustomerOrder')) {
        # only check order events if this is an ebay order
        my $IsEbayOrder = scalar @{ LoadClassByAlias('EbayTransaction')->findObjects('ByCustomerOrderID',[$Object->id]) };
        $IsEbayEvent = 1 if $IsEbayOrder;
    }

    # return if this is not a Ebay email event
    return unless $IsEbayEvent;

    $hParams->{'SendMail'} = $Object->getSite()->get('EbaySendMail');
}

1;
