package DE_EPAGES::GoogleAnalytics::t::unit::UniversalAnalyticsHandler;
use base DE_EPAGES::Test::API::UnitTest::Test;

use strict;

use DE_EPAGES::GoogleAnalytics::API::TLE::UniversalAnalyticsHandler;
use Test::More;

sub test {
    my $self = shift;

    $self->test_uaPageView_Basket();
    $self->test_upPageView_User();
    $self->test_upPageView_ShoppingList();
    $self->test_upPageView_ArbitraryObject();
    done_testing();

    return;
}

sub test_uaPageView_Basket {
    my $self = shift;

    my $Handler               = DE_EPAGES::GoogleAnalytics::API::TLE::UniversalAnalyticsHandler->new();
    my $hTrackingData         = $Handler->uaPageView( $self->memory->get('MockedBasket'), 'View' );
    my $hExpectedTrackingData = {
        'Path'  => '/Shops/DemoShop/Basket',
        'Title' => 'Basket'
    };

    is_deeply( $hTrackingData, $hExpectedTrackingData, 'uaPageView Basket' );

    return;
}

sub test_upPageView_User {
    my $self = shift;

    my $Handler               = DE_EPAGES::GoogleAnalytics::API::TLE::UniversalAnalyticsHandler->new();
    my $hTrackingData         = $Handler->uaPageView( $self->memory->get('MockedUser'), 'View' );
    my $hExpectedTrackingData = {
        'Path'  => '/Shops/DemoShop/ANONYMIZED_USER_PATH',
        'Title' => 'ANONYMIZED_USER_NAME'
    };

    is_deeply( $hTrackingData, $hExpectedTrackingData, 'uaPageView User' );

    return;
}

sub test_upPageView_ShoppingList {
    my $self = shift;

    my $Handler               = DE_EPAGES::GoogleAnalytics::API::TLE::UniversalAnalyticsHandler->new();
    my $hTrackingData         = $Handler->uaPageView( $self->memory->get('MockedShoppingList'), 'View' );
    my $hExpectedTrackingData = {
        'Path'  => '/Shops/DemoShop/ANONYMIZED_SHOPPING_LIST_PATH',
        'Title' => 'ANONYMIZED_SHOPPING_LIST_NAME'
    };

    is_deeply( $hTrackingData, $hExpectedTrackingData, 'uaPageView ShoppingList' );

    return;
}

sub test_upPageView_ArbitraryObject {
    my $self = shift;

    my $Handler               = DE_EPAGES::GoogleAnalytics::API::TLE::UniversalAnalyticsHandler->new();
    my $hTrackingData         = $Handler->uaPageView( $self->memory->get('MockedArbitraryObject'), 'View' );
    my $hExpectedTrackingData = {
        'Path'  => '/Shops/DemoShop/Products/mp_12345',
        'Title' => 'Mocked Product'
    };

    is_deeply( $hTrackingData, $hExpectedTrackingData, 'uaPageView User' );

    return;
}

sub init {
    my $self = shift;

    $self->initMockedShop();
    $self->initMockedBasket();
    $self->initMockedUser();
    $self->initMockedShoppingList();
    $self->initMockedArbitraryObject();

    return;
}

sub initMockedShop {
    my $self = shift;

    my $MockifyShop = $self->mockFactory->buildShop(
        {
            'Path' => '/Shops/DemoShop'
        }
    );

    $MockifyShop->addMock( 'pathString', sub { return '/Shops/DemoShop'; } );
    $self->memory->add( 'MockedShop', $MockifyShop->getMockObject() );

    return;
}

sub initMockedBasket {
    my $self = shift;

    my $MockifyBasket = $self->mockFactory->buildBasket(
        {
            'Site' => $self->memory->get('MockedShop')
        }
    );
    my $MockifyBasketClass = $self->mockFactory->build(
        'DE_EPAGES::Order::API::Object::Basket',
        {
            'Alias' => 'Basket'
        }
    );

    $MockifyBasket->addMock( 'class',   sub { return $MockifyBasketClass->getMockObject(); } );
    $MockifyBasket->addMock( 'getSite', sub { return $self->memory->get('MockedShop'); } );
    $self->memory->add( 'MockedBasket', $MockifyBasket->getMockObject() );

    return;
}

sub initMockedUser {
    my $self = shift;

    my $MockifyUser = $self->mockFactory->buildUser(
        {
            'Site'  => $self->memory->get('MockedShop'),
            'Class' => $self->mockFactory->build(
                'DE_EPAGES::Permission::API::Object::User',
                {
                    'Alias' => 'User'
                }
            )
        }
    );
    my $MockifyUserClass = $self->mockFactory->build(
        'DE_EPAGES::Permission::API::Object::User',
        {
            'Alias' => 'User'
        }
    );

    $MockifyUser->addMock( 'class',   sub { return $MockifyUserClass->getMockObject(); } );
    $MockifyUser->addMock( 'getSite', sub { return $self->memory->get('MockedShop'); } );
    $self->memory->add( 'MockedUser', $MockifyUser->getMockObject() );

    return;
}

sub initMockedShoppingList {
    my $self = shift;

    my $MockifyShoppingList = $self->mockFactory->build(
        'DE_EPAGES::ShoppingList::API::Object::ShoppingList',
        {
            'Path'        => '/Shops/DemoShop/Users/mmustermann/ShoppingLists/wish-list',
            'NameOrAlias' => 'Wish List'
        }
    );
    my $MockifyShoppingListClass = $self->mockFactory->build(
        'DE_EPAGES::ShoppingList::API::Object::ShoppingList',
        {
            'Alias' => 'ShoppingList'
        }
    );

    $MockifyShoppingList->addMock( 'class',   sub { return $MockifyShoppingListClass->getMockObject(); } );
    $MockifyShoppingList->addMock( 'getSite', sub { return $self->memory->get('MockedShop'); } );
    $self->memory->add( 'MockedShoppingList', $MockifyShoppingList->getMockObject() );

    return;
}

sub initMockedArbitraryObject {
    my $self = shift;

    my $MockifyProduct = $self->mockFactory->buildProduct(
        {
            'Path'        => '/Shops/DemoShop/Products/mp_12345',
            'NameOrAlias' => 'Mocked Product'
        }
    );
    my $MockifyProductClass = $self->mockFactory->build(
        'DE_EPAGES::Product::API::Object::Product',
        {
            'Alias' => 'ProductClass'
        }
    );

    $MockifyProduct->addMock( 'class',   sub { return $MockifyProductClass->getMockObject(); } );
    $MockifyProduct->addMock( 'getSite', sub { return $self->memory->get('MockedShop'); } );
    $self->memory->add( 'MockedArbitraryObject', $MockifyProduct->getMockObject() );

    return;
}

__PACKAGE__->runScript();
1;
