use DE_EPAGES::Cartridge::API::Table::Cartridge qw ( ExistsCartridgeByPackage );
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Core::API::Warning qw ( Warning );
use DE_EPAGES::Database::API::Connection qw ( RunOnStore );
use DE_EPAGES::Object::API::Factory qw ( LoadClassByAlias LoadObject );
use DE_EPAGES::WebInterface::API::MessageCenter qw ( SynchronizeCache );
use Getopt::Long;
use Time::HiRes qw ( time );

use strict;

sub Main {

    local $| = 1;

    my $Password;
    my $StoreName;
    my $Help;
    my $NoOutput;
    my $FileName;

    GetOptions(
        'help'          => \$Help,
        'nooutput'      => \$NoOutput,
        'passwd=s'      => \$Password,
        'storename=s'   => \$StoreName,
        'filename=s'    => \$FileName,
    );

    usage() if $Help;
    usage( 'Missing required parameter -storename' ) unless defined $StoreName;

    my $time1 = time;

    RunOnStore(
        Store => $StoreName,
        DBPassword => $Password,
        Sub => sub  {
            if (not ExistsCartridgeByPackage('DE_EPAGES::Ogone')){
                print 'Store: '.$StoreName.": Cartridge Ogone is not installed.\n" unless ($NoOutput);
                return;
            }

            my $PaymentMethodOgoneClass = LoadClassByAlias('PaymentMethodOgone');
            my $aPaymentMethodIds = $PaymentMethodOgoneClass->findObjects('ByClassID',[$PaymentMethodOgoneClass->id]);

            my $PaymentMethodPostfinanceClass = LoadClassByAlias('PaymentMethodPostfinance');

            foreach my $PaymentMethodId (@{$aPaymentMethodIds}){

                my $PaymentMethodOgone = LoadObject($PaymentMethodId);
                my $PaymentTypeAlias = $PaymentMethodOgone->get('PaymentType')->get('Alias');

               if ($PaymentTypeAlias eq 'Postfinance') {
                    $PaymentMethodOgone->set({'Class' => $PaymentMethodPostfinanceClass});

                    unless($NoOutput){
                        my $ShopAlias = $PaymentMethodOgone->getSite()->alias();
                        my $PaymentMethodAlias = $PaymentMethodOgone->alias();
                        print "The payment method: '$PaymentMethodAlias' of '$StoreName - $ShopAlias' class has changed to PaymentMethodPostfinance \n";
                    }
               }
            }
        },
    );

    my $time2 = time;
    my $seconds = $time2-$time1;
    my $logmsg = sprintf ('took %.3f seconds', $seconds);
    print "\n".$logmsg."\n\n" unless $NoOutput;

    eval { SynchronizeCache(); };
    Warning( GetError() ) if ExistsError();
}

sub usage {
    my ($ErrorMessage) = @_;
    print STDERR $ErrorMessage . "\n" if ($ErrorMessage);

    print <<END_USAGE;
Description:
    Change Postfinance PaymentMethod class from PaymentMethodOgone to PaymentMethodPostfinance.
Usage:
    perl $0 [options] [flags]
options:
    -passwd       database user password              ()
    -storename    name of store                       ()
flags:
    -nooutput     do not print any output
    -help         show the command line options
Example:
    perl $0 -storename Store
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main
);
