#==============================================================================
# package      DE_EPAGES::Presentation::API::LocaleHandler
# state        public
#----------------------------------------------------------------------------------------
# description  This package provides the helper functions of the locale handler.
#========================================================================================
package DE_EPAGES::Presentation::API::LocaleHandler;
use strict;

use base qw ( Exporter );

use DE_EPAGES::Core::API::TestParameter qw ( TestInteger );
use DE_EPAGES::Object::API::Language qw ( GetCodeByLanguageID );

our @EXPORT_OK = qw (
    AddLanguageToURL
) ;

#========================================================================================
# function     AddLanguageToURL
# state        public
#----------------------------------------------------------------------------------------
# syntax       AddLanguageToURL($URL, $AltLanguageID, $LanguageID)
#----------------------------------------------------------------------------------------
# description  Converts a given AltLanguageID to the fitting language code and adds this
#               to the given URL if it is different to the given LanguageID
#----------------------------------------------------------------------------------------
# input        $URL | Unity storefront URL | string
# input        $AltLanguageID | language id | string
# input        $LanguageID | language id | string
# return       $URL | url with added locale | string
#========================================================================================
sub AddLanguageToURL {
    my ($UnityStorefrontURL, $AltLanguageID, $LanguageID) = @_;

    # return if we have no parameter (important for normal shops)
    return undef unless defined $UnityStorefrontURL; 

    # do not add anything in case of missing AltLanguageID
    return $UnityStorefrontURL unless defined $AltLanguageID;

    TestInteger('AltLanguageID', $AltLanguageID);
    if (defined $LanguageID) {
        TestInteger('LanguageID', $LanguageID);
        # do not add any language to the path in case of the default language
        return $UnityStorefrontURL if $AltLanguageID == $LanguageID;
    }
    # convert language id to the related language code
    my $LanguageCode = GetCodeByLanguageID($AltLanguageID);
    # add the locale to the URL after the top level domain
    $UnityStorefrontURL =~ s/^(\w+:\/\/[^\/#?]+)(.*)/$1\/$LanguageCode$2/;

    return $UnityStorefrontURL;
}

1;
