#========================================================================================
# package      DE_EPAGES::Presentation::t::LocaleHandler
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for the TLE functions of the package
#               DE_EPAGES::Presentation::API::TLE::LocaleHandler
#========================================================================================
package DE_EPAGES::Presentation::t::LocaleHandler;

use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::Presentation::API::TLE::LocaleHandler;
use DE_EPAGES::TLE::API::BaseProcessor;
use Test::Exception;
use Test::MockModule;
use Test::More;
use strict;

use constant WEBURLUNITYSSL => 'http://www.my-testshop.com';
use constant PATH => '/p/Knoedelschleudermaschine';
use constant QUERY => '?shop=my-shop';
use constant WEBURLUNITYSSLWITHPATH => WEBURLUNITYSSL . PATH;
use constant WEBURLUNITYSSLWITHQUERY => WEBURLUNITYSSL . QUERY;
use constant WEBURLUNITYSSLWITHQUERYANDSLASH => WEBURLUNITYSSL . '/' . QUERY;
use constant LANGUAGE_ID_DE => 1;
use constant LANGUAGE_ID_EN => 2;
use constant LANGUAGE_ID_RU => 3;
use constant LANGUAGE_CODE_DE => 'de';
use constant LANGUAGE_CODE_EN => 'en';
use constant LANGUAGE_CODE_RU => 'ru';

use feature 'switch';

sub test {
    _test_AddLanguageToUnitySfURL();

    done_testing();
}

sub _test_AddLanguageToUnitySfURL {
    # mock helper function GetCodeByLanguageID
    my $module = Test::MockModule->new('DE_EPAGES::Presentation::API::LocaleHandler');
    $module->mock('GetCodeByLanguageID', sub {
        my ($LanguageID) = @_;
        given ($LanguageID) {
            when (LANGUAGE_ID_DE) {
                return LANGUAGE_CODE_DE;
            }
            when (LANGUAGE_ID_EN) {
                return LANGUAGE_CODE_EN;
            }
            when (LANGUAGE_ID_RU) {
                return LANGUAGE_CODE_RU;
            }
        }
    });

    # Build a wrapper function to use the TLE function "AddLanguageToUnitySfURL" in this Perl code
    my $Processor = DE_EPAGES::TLE::API::BaseProcessor->new;
    my $LocaleHandler = DE_EPAGES::Presentation::API::TLE::LocaleHandler->new();
    $LocaleHandler->register($Processor);
    my $AddLanguageToUnitySfURL = sub {
        my ($URL, $AltLanguageID, $LanguageID) = @_;
        $Processor->callBlock('AddLanguageToUnitySfURL', sub {[ $URL, $AltLanguageID, $LanguageID ]});
    };

    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSL), WEBURLUNITYSSL, "No changes without given AltLanguageID");
    throws_ok(sub { $AddLanguageToUnitySfURL->(WEBURLUNITYSSL, 'abc') }, qr/FORMAT_NOT_INTEGER/,
        "Dies without integer AltLanguageID");
    throws_ok(sub { $AddLanguageToUnitySfURL->(WEBURLUNITYSSL, LANGUAGE_ID_DE, 'abc') }, qr/FORMAT_NOT_INTEGER/,
        "Dies without integer LanguageID");
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSL, LANGUAGE_ID_DE, LANGUAGE_ID_DE), WEBURLUNITYSSL,
        "No changes with identical AltLanguageID and LanguageID");
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSL, LANGUAGE_ID_EN, LANGUAGE_ID_DE),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_EN, "Added correct Language extension " . '/' . LANGUAGE_CODE_EN);
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSL, LANGUAGE_ID_RU, LANGUAGE_ID_DE),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_RU, "Added correct Language extension " . '/' . LANGUAGE_CODE_RU);
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSLWITHPATH, LANGUAGE_ID_DE, LANGUAGE_ID_DE), WEBURLUNITYSSLWITHPATH,
        "No changes with identical AltLanguageID and LanguageID and with path");
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSLWITHPATH, LANGUAGE_ID_EN, LANGUAGE_ID_DE),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_EN . PATH, "Added correct Language extension " . '/'
        . LANGUAGE_CODE_EN . ' into path');
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSLWITHPATH, LANGUAGE_ID_RU, LANGUAGE_ID_DE),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_RU . PATH, "Added correct Language extension " . '/'
        . LANGUAGE_CODE_RU . ' into path');
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSL, LANGUAGE_ID_DE, LANGUAGE_ID_EN),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_DE, "Added correct Language extension " . '/'
        . LANGUAGE_CODE_DE . ' with default language ' . LANGUAGE_CODE_EN);
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSLWITHPATH, LANGUAGE_ID_DE, LANGUAGE_ID_RU),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_DE . PATH, "Added correct Language extension "
        . '/' . LANGUAGE_CODE_DE . ' into path' . ' with default language ' . LANGUAGE_CODE_EN);
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSLWITHQUERY, LANGUAGE_ID_EN, LANGUAGE_ID_DE),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_EN . QUERY, "Added correct Language extension "
        . '/' . LANGUAGE_CODE_EN . ' before query');
    is($AddLanguageToUnitySfURL->(WEBURLUNITYSSLWITHQUERYANDSLASH, LANGUAGE_ID_EN, LANGUAGE_ID_DE),
        WEBURLUNITYSSL . '/' . LANGUAGE_CODE_EN . '/' . QUERY, "Added correct Language extension "
        . '/' . LANGUAGE_CODE_EN. ' before query with slash');

    $module->unmock('GetCodeByLanguageID');
}

__PACKAGE__->runScript;

1;
