#========================================================================================
# package      DE_EPAGES::SIA::API::Cartridge
# base         DE_EPAGES::Design::API::PaymentInstaller
# state        public
#----------------------------------------------------------------------------------------
# description  This is the main cartridge class for install/patch/uninstall.
#========================================================================================
package DE_EPAGES::SIA::API::Cartridge;
use base DE_EPAGES::Payment::API::PaymentInstaller;
use DE_EPAGES::Object::API::XML::ObjectDeleteHandler qw (DeleteObjects);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);
use DE_EPAGES::SIA::API::SIAConfig;

use strict;

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer = DE_EPAGES::SIA::API::Cartridge->new(%options);
#----------------------------------------------------------------------------------------
# description  Creates a new installer object of DE_EPAGES::SIA.
#----------------------------------------------------------------------------------------
# input        %options | options for un/install
#               <ul>
#                 <li>IsRecursive - recursive un/installation of required or dependent
#                     cartridges
#               </ul>
#               | hash
# return       $Installer | cartridge installer | object
#========================================================================================
sub new {
    my ( $class, %options ) = @_;

    my $self = __PACKAGE__->SUPER::new(
        %options,
        'CartridgeDirectory' => 'DE_EPAGES/SIA',
        'Version'            => '7.15.0',
        'Patches'            => ['7.2.0','7.3.0','7.4.0','7.5.0','7.6.0','7.7.0','7.8.0','7.9.0','7.10.0','7.11.0','7.12.0','7.13.0','7.14.0'],
    );

    return bless $self, $class;
}

#========================================================================================
# function     install
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->install;
#----------------------------------------------------------------------------------------
# description  Installs the cartridge.
#========================================================================================
sub install {
    my $self = shift;

    $self->startInstall();
    $self->SUPER::install();
    ImportObjects( $self->xmlDirectory . '/SIAConfig.xml' );
    $self->createDefaultPaymentNetworks();
    $self->finishInstall();

    return;
}

#========================================================================================
# function     uninstall
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->uninstall;
#----------------------------------------------------------------------------------------
# description  Uninstalls the cartridge.
#========================================================================================
sub uninstall {
    my $self = shift;

    $self->startUninstall();
    DeleteObjects( $self->xmlDirectory . '/SIAConfig.xml' );

    $self->SUPER::uninstall();
    $self->finishUninstall();

    return;
}

sub createDefaultPaymentNetworks {
    my $self = shift;

    my $SiaConfig = DE_EPAGES::SIA::API::SIAConfig->new( 'IsInTestMode' => 0 );
    $SiaConfig->addDefaultPaymentNetworks();

    my $SiaTestConfig = DE_EPAGES::SIA::API::SIAConfig->new( 'IsInTestMode' => 1 );
    $SiaTestConfig->addDefaultPaymentNetworks();

    return;
}

1;
